@@ -13,6 +13,7 @@ from gaia_sdk.graphql.request.enumeration.SkillState import SkillState
 from gaia_sdk.graphql.request.enumeration.Order import Order
 from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
 from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeType import EdgeType
 
 class BehaviourNodeExecution:
     """
@@ -32,32 +33,20 @@ class BehaviourNodeExecution:
         return {'dictionary': self.dictionary}
 
     @property
-    def process_instance_id(self) -> Uuid:
-        return Uuid(self.dictionary.get("processInstanceId"))
+    def activity_id(self) -> String:
+        return String(self.dictionary.get("activityId"))
     @property
-    def node_instance_id(self) -> Uuid:
-        return Uuid(self.dictionary.get("nodeInstanceId"))
+    def reference(self) -> Uuid:
+        return Uuid(self.dictionary.get("reference"))
+    @property
+    def qualifier(self) -> String:
+        return String(self.dictionary.get("qualifier"))
     @property
     def state(self) -> String:
         return String(self.dictionary.get("state"))
     @property
-    def execution_group_id(self) -> Uuid:
-        return Uuid(self.dictionary.get("executionGroupId"))
-    @property
-    def node_id(self) -> Uuid:
-        return Uuid(self.dictionary.get("nodeId"))
-    @property
-    def process_id(self) -> Uuid:
-        return Uuid(self.dictionary.get("processId"))
-    @property
     def type(self) -> String:
         return String(self.dictionary.get("type"))
     @property
-    def transitions(self) -> Struct:
-        return Struct(self.dictionary.get("transitions"))
-    @property
-    def timestamp(self) -> ISO8601:
-        return ISO8601(self.dictionary.get("timestamp"))
-    @property
-    def parent_process_id(self) -> Uuid:
-        return Uuid(self.dictionary.get("parentProcessId"))
+    def created(self) -> ISO8601:
+        return ISO8601(self.dictionary.get("created"))
