@@ -1,6 +1,7 @@
 
 from gaia_sdk.graphql.response.type.BehaviourExecution import BehaviourExecution
 from gaia_sdk.graphql.response.type.BehaviourNodeExecution import BehaviourNodeExecution
+from gaia_sdk.graphql.response.type.BehaviourExecutionDetail import BehaviourExecutionDetail
 
 from typing import List
 Uuid = str
@@ -15,6 +16,7 @@ from gaia_sdk.graphql.request.enumeration.SkillState import SkillState
 from gaia_sdk.graphql.request.enumeration.Order import Order
 from gaia_sdk.graphql.request.enumeration.OrderByField import OrderByField
 from gaia_sdk.graphql.request.enumeration.EdgeOrderByField import EdgeOrderByField
+from gaia_sdk.graphql.request.enumeration.EdgeType import EdgeType
 
 class Experience:
     """
@@ -34,6 +36,9 @@ class Experience:
         return {'dictionary': self.dictionary}
 
     @property
+    def behaviour_execution(self) -> BehaviourExecutionDetail:
+        return BehaviourExecutionDetail(self.dictionary.get("behaviourExecution"))
+    @property
     def behaviour_executions(self) -> List[BehaviourExecution]:
         return list(map(lambda x: BehaviourExecution(x), self.dictionary.get("behaviourExecutions")))
     @property
